!-------------------------------------------------------------------------------

!                      Code_Saturne version 6.0
!                      ------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2019 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_modules.f90
!>
!> \brief User-defined module: it allows to create any user array.
!>
!> See \subpage cs_user_modules for examples.
!>
!> This file is compiled before all other user Fortran files.
!> To ensure this, it must not be renamed.
!>
!> The user may define an arbitrary number of modules here, even though
!> only one is defined in the example.
!
!> \cond DOXYGEN_SHOULD_SKIP_THIS

!-------------------------------------------------------------------------------

module user_module

implicit none

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! ajouts KD/CF 16/2/21
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

!!!!!!!! PARAMETRES PHYSIQUES !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

! Declarations des grandeurs non parametrees

! Declaration des grandeurs parametrables
  double precision, parameter :: ru_reyref = 392.24 ! ru_U_inf * ru_Ly / nu
  double precision, parameter :: ru_U_inf = 2.d1 ! vitesse de l'eclt amont
  double precision, parameter :: ru_int_turb = 1.d-2 ! intensite turbulente
  double precision, parameter :: pii = 3.14159d0



!!!!!!!! PARAMETRES GEOMETRIQUES !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

! Declaration des grandeurs parametrables
  integer, parameter :: iu_Nx = 32
  integer, parameter :: iu_Ny = 42
  integer, parameter :: iu_Nz = 32
  double precision, parameter :: ru_prog = 1.1d0
  double precision :: ru_totvol
  double precision, parameter :: ru_Lx = 8.d0
  double precision, parameter :: ru_Ly = 1.d0
  double precision, parameter :: ru_Lz = 4.d0
  double precision, parameter :: ru_tphys = ru_Lx / ru_U_inf
  double precision, parameter :: ru_utau = 1.d0
  double precision :: ru_dtfilt 
  double precision, parameter :: ru_couref = 2.d-1


!!!!!!!!! CONSTANTES HTLES ET MODELE DE TURBULENCE!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

  double precision, parameter :: ru_gamma = 2.d0/3.d0
  double precision, parameter :: ru_beta0 = 4.4d-1
  double precision, parameter :: ru_cmu = 9.d-2
  integer, parameter :: ihtles = 1
  integer, parameter :: iu_igam = 0 ! terme GAM ; =0 : rien, =1 : Jeroen
  integer, parameter :: iu_if = 0
end module user_module


!-------------------------------------------------------------------------------

!> (DOXYGEN_SHOULD_SKIP_THIS) \endcond
